Skip to contents

Displays a summary of a satscan_table object including its kind, metadata, and a preview of the data.

Usage

# S3 method for class 'satscan_table'
print(x, ...)

Arguments

x

A satscan_table object.

...

Additional arguments passed to print for the data preview.

Value

Invisibly returns the input object.