Creates a new ss_tbl object, which is a vctrs subclass of data.frame tailored for SaTScan data.
Usage
new_ss_tbl(data, type, roles, spec = list())Creates a new ss_tbl object, which is a vctrs subclass of data.frame tailored for SaTScan data.
new_ss_tbl(data, type, roles, spec = list())